# -*- coding: utf-8 -*-
#
# Copyright (C) 2008, 2010  Fabian Knittel <fabian.knittel@avona.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.

try:
    from elixir import LargeBinary
except ImportError:
    # Add compat name for SQLAlchemy < 0.6
    from elixir import Binary as LargeBinary
from elixir import *
import datetime
import re

class DeliveredMail(Entity):
    using_options(tablename = 'oralexam_deliveredmail')

    sender = Field(Unicode(255), required = True)
    subject = Field(Unicode(255), required = True)
    date = Field(DateTime(), required = True, default = datetime.datetime.now)
    attachments = OneToMany('DeliveredAttachment')

    def __repr__(self):
        return '<DeliveredMail sender=%s subject=%s date=%s>' % (
                repr(self.sender), repr(self.subject), repr(self.date))

def filter_file_name(file_name):
    safe_char = re.compile(ur'[-\.\wÄäÖöÜüß]')
    return filter(lambda c: safe_char.match(c), file_name)

class DeliveredAttachment(Entity):
    using_options(tablename = 'oralexam_deliveredattachment')

    name = Field(Unicode(255), required = True)
    mail = ManyToOne('DeliveredMail')
    data = Field(LargeBinary())

    def __repr__(self):
        return '<DeliveredAttachment %s>' % repr(self.name)

    @property
    def unique_file_name(self):
        return '%s-%d-%s' % (self.mail.date.strftime('%Y%m%d-%H%M%S'),
                self.mail.id, filter_file_name(self.name))

# Create the SQLAlchemy table and mapper instances for the above entities.
setup_all()

# vim:set textwidth=80 tabstop=8 softtabstop=4 shiftwidth=4 et:
